'use client';

import Link from 'next/link';
import {
  HandHeart,
  Headset,
  Heart,
  Home,
  Library,
  LogOut,
  Package,
  Search,
  Settings,
  ShoppingCart,
  Telescope,
  User,
} from 'lucide-react';
import { cn } from '@/lib/utils';

import { usePathname } from 'next/navigation';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Sheet, SheetContent, SheetTrigger } from '@/components/ui/sheet';
import Logo from '@/components/ui/logo';
import { Separator } from '@/components/ui/separator';

export default function AppLayout({ children }: { children: React.ReactNode }) {
  const pathname = usePathname();

  return (
    <div className='grid min-h-screen w-full md:grid-cols-[220px_1fr] lg:grid-cols-[280px_1fr]'>
      <div className='hidden border-r bg-muted/40 md:block'>
        <div className='flex h-full max-h-screen flex-col gap-8 lg:gap-12'>
          <div className='flex h-16 items-center px-4 lg:h-[72px] lg:px-6'>
            <Link href='/app' className=''>
              <Logo className='h-8 w-auto' />
            </Link>
          </div>

          <div className='flex-1'>
            <nav className='grid items-start px-2 text-sm font-medium lg:px-4'>
              <Link
                href='/app'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Home className='h-4 w-4' />
                Home
              </Link>
              <Link
                href='/app/explore'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/explore'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Telescope className='h-4 w-4' />
                Explore
              </Link>
              <Link
                href='/app/cart'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/cart'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <ShoppingCart className='h-4 w-4' />
                Cart
              </Link>
              <Link
                href='/app/orders'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/orders'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Package className='h-4 w-4' />
                Orders
              </Link>
              <Link
                href='/app/wishlist'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/wishlist'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Heart className='h-4 w-4' />
                Wishlist
              </Link>
              <Link
                href='/app/listings'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/listings'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Library className='h-4 w-4' />
                Your Listings
              </Link>
              <Link
                href='/app/donate'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/donate'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <HandHeart className='h-4 w-4' />
                Donate
              </Link>

              <Separator className='my-4' />

              <Link
                href='/app/profile'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/profile'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <User className='h-4 w-4' />
                Profile
              </Link>
              <Link
                href='/app/settings'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/settings'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Settings className='h-4 w-4' />
                Settings
              </Link>
              <Link
                href='/app/support'
                className={cn(
                  'flex items-center gap-3 rounded-lg px-3 py-2 transition-all hover:text-primary',
                  pathname === '/app/support'
                    ? 'bg-muted text-primary'
                    : 'text-muted-foreground'
                )}
              >
                <Headset className='h-4 w-4' />
                Help & Support
              </Link>
              <Button
                size='sm'
                variant='ghost'
                className='flex items-center justify-start gap-3 rounded-lg px-3 py-2 text-muted-foreground transition-all hover:bg-inherit hover:text-primary'
              >
                <LogOut className='h-4 w-4' />
                Logout
              </Button>
            </nav>
          </div>
        </div>
      </div>

      <div className='flex flex-col'>
        <header className='flex h-16 items-center gap-4 border-b bg-muted/40 px-4 lg:h-[72px] lg:px-6'>
          <Sheet>
            <SheetTrigger asChild>
              <Button
                variant='ghost'
                size='icon'
                className='shrink-0 md:hidden'
              >
                <svg
                  strokeWidth='1.5'
                  viewBox='0 0 24 24'
                  fill='none'
                  xmlns='http://www.w3.org/2000/svg'
                  className='h-5 w-5'
                >
                  <path
                    d='M3 5H11'
                    stroke='currentColor'
                    strokeWidth='1.5'
                    strokeLinecap='round'
                    strokeLinejoin='round'
                  ></path>
                  <path
                    d='M3 12H16'
                    stroke='currentColor'
                    strokeWidth='1.5'
                    strokeLinecap='round'
                    strokeLinejoin='round'
                  ></path>
                  <path
                    d='M3 19H21'
                    stroke='currentColor'
                    strokeWidth='1.5'
                    strokeLinecap='round'
                    strokeLinejoin='round'
                  ></path>
                </svg>
                <span className='sr-only'>Toggle navigation menu</span>
              </Button>
            </SheetTrigger>
            <SheetContent side='left' className='flex flex-col'>
              <nav className='grid gap-2 text-lg font-medium'>
                <Link href='/app' className='mb-6'>
                  <Logo className='h-8 w-auto' />
                </Link>

                <Link
                  href='/app'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Home className='h-5 w-5' />
                  Home
                </Link>
                <Link
                  href='/app/explore'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/explore'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Telescope className='h-5 w-5' />
                  Explore
                </Link>
                <Link
                  href='/app/cart'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/cart'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <ShoppingCart className='h-5 w-5' />
                  Cart
                </Link>
                <Link
                  href='/app/orders'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/orders'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Package className='h-5 w-5' />
                  Orders
                  {/* <Badge className='ml-auto flex h-6 w-6 shrink-0 items-center justify-center rounded-full'>
                    6
                  </Badge> */}
                </Link>
                <Link
                  href='/app/wishlist'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/wishlist'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Heart className='h-5 w-5' />
                  Wishlist
                </Link>
                <Link
                  href='/app/listings'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/listings'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Library className='h-5 w-5' />
                  Your Listings
                </Link>
                <Link
                  href='/app/donate'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/donate'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <HandHeart className='h-5 w-5' />
                  Donate
                </Link>

                <Separator className='my-4' />

                <Link
                  href='/app/profile'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/profile'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <User className='h-5 w-5' />
                  Profile
                </Link>
                <Link
                  href='/app/settings'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/settings'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Settings className='h-5 w-5' />
                  Settings
                </Link>
                <Link
                  href='/app/support'
                  className={cn(
                    'mx-[-0.65rem] flex items-center gap-4 rounded-md px-3 py-2 hover:text-foreground',
                    pathname === '/app/support'
                      ? 'bg-muted text-foreground'
                      : 'text-muted-foreground'
                  )}
                >
                  <Headset className='h-5 w-5' />
                  Help & Support
                </Link>
                <Button
                  variant='ghost'
                  size='lg'
                  className='mx-[-0.65rem] flex items-center justify-start gap-4 rounded-md px-3 py-2 text-lg font-medium text-muted-foreground hover:bg-inherit hover:text-foreground'
                >
                  <LogOut className='h-5 w-5' />
                  Logout
                </Button>
              </nav>
            </SheetContent>
          </Sheet>

          <div className='w-full flex-1'>
            <form>
              <div className='relative'>
                <Search className='absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground' />
                <Input
                  type='search'
                  placeholder='Search here...'
                  className='w-full appearance-none bg-background pl-8 shadow-none md:w-2/3 lg:w-1/3'
                />
              </div>
            </form>
          </div>
        </header>

        {children}
      </div>
    </div>
  );
}
